searchData={"items":[{"type":"module","title":"LivePhone","doc":"[![Actions Status](https://github.com/nkezhaya/live_phone/actions/workflows/elixir.yml/badge.svg)](https://github.com/nkezhaya/live_phone/actions/workflows/elixir.yml?query=workflow%3ACI)\n[![hex.pm](https://img.shields.io/hexpm/v/live_phone.svg)](https://hexdocs.pm/live_phone/LivePhone.html)\n\n# LivePhone\n\nA Phoenix LiveComponent for phone number input fields, inspired by [`intl-tel-input`](https://github.com/jackocnr/intl-tel-input).\n\nBased on [`ISO`](https://github.com/nkezhaya/iso) and [`ex_phone_number`](https://github.com/socialpaymentsbv/ex_phone_number), which in turn is based on [libphonenumber](https://github.com/google/libphonenumber).","ref":"LivePhone.html"},{"type":"module","title":"Installation - LivePhone","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `live_phone` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_phone, \"~> 0.8\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at [https://hexdocs.pm/live_phone](https://hexdocs.pm/live_phone).\n\nTo your `assets/package.json` file add:\n```\n\"live_phone\": \"file:../deps/live_phone\",\n```\n\nTo your `app.js` add something like:\n```\nimport LivePhone from \"live_phone\"\nlet Hooks = {}\nHooks.LivePhone = LivePhone\n```\n\nAnd finally to your CSS add:\n```\n@import \"../../deps/live_phone/assets/live_phone\";\n```","ref":"LivePhone.html#module-installation"},{"type":"module","title":"Usage - LivePhone","doc":"Usage is pretty simple, and there is an example Phoenix project included in the `./example` directory of this repository.\n\n```elixir\n<.live_component\n  module={LivePhone}\n  id=\"phone\"\n  form={:user}\n  field={:phone}\n  tabindex={0}\n  preferred={[\"US\", \"CA\"]} />\n```\n\nThis will result in a form field with the name `user[phone]`. You can specify just the `name` manually if desired, but when you add the `form` option the name will be generated via `Phoenix.HTML.Form.input_name/2`. So this should behave like a regular input field.\n\nWith `preferred` you can set a list of countries that you believe should be on top always. The currently selected country will also be on top automatically.","ref":"LivePhone.html#module-usage"},{"type":"module","title":"Example - LivePhone","doc":"In the `example/` directory you will find a minimal Phoenix application to demonstrate `LivePhone` in usage.","ref":"LivePhone.html#module-example"},{"type":"module","title":"Browser Tests (chromedriver) - LivePhone","doc":"To run the browser tests you need to install `chromedriver` (`brew install chromedriver` on MacOS) and it has to be running already. The tests are excluded by default, but you can include them with `--include browser`. See below:\n\nAn \"invalid session id\" error can usually be fixed by upgrading chromedriver.\n\n```\n$ chromedriver --verbose --url-base=/wd/hub # hound assumes default port 9515)\n$ mix test --include browser\n```","ref":"LivePhone.html#module-browser-tests-chromedriver"},{"type":"function","title":"LivePhone.set_value/2","doc":"","ref":"LivePhone.html#set_value/2"},{"type":"module","title":"LivePhone.Country","doc":"The `LivePhone.Country` struct holds minimal information about a country, but\nit should be enough data for `LivePhone` to work its magic.","ref":"LivePhone.Country.html"},{"type":"function","title":"LivePhone.Country.from_iso/1","doc":"Converts the given `iso_country` tuple into a `LivePhone.Country` struct.","ref":"LivePhone.Country.html#from_iso/1"},{"type":"function","title":"Examples - LivePhone.Country.from_iso/1","doc":"iex> ISO.countries() |> Map.to_list() |> Enum.find(fn {cc, _} -> cc == \"SL\" end) |> LivePhone.Country.from_iso()\n    %LivePhone.Country{\n      preferred: false,\n      region_code: \"232\",\n      flag_emoji: \"🇸🇱\",\n      code: \"SL\",\n      name: \"Sierra Leone\"\n    }\n\n    iex> LivePhone.Country.from_iso({\"US\", %{\"name\" => \"United States\"}})\n    %LivePhone.Country{\n      preferred: false,\n      region_code: \"1\",\n      flag_emoji: \"🇺🇸\",\n      code: \"US\",\n      name: \"United States\"\n    }","ref":"LivePhone.Country.html#from_iso/1-examples"},{"type":"function","title":"LivePhone.Country.get/1","doc":"This function will retrieve a `Country` by its country code. Also accepts a\n`%PhoneNumber{}` struct.","ref":"LivePhone.Country.html#get/1"},{"type":"function","title":"Examples - LivePhone.Country.get/1","doc":"```elixir\n  iex> LivePhone.Country.get(\"US\")\n  {:ok, %LivePhone.Country{code: \"US\", flag_emoji: \"🇺🇸\", name: \"United States of America (the)\", preferred: false, region_code: \"1\"}}\n\n  iex> LivePhone.Country.get(\"FAKE\")\n  {:error, :not_found}\n\n```","ref":"LivePhone.Country.html#get/1-examples"},{"type":"function","title":"LivePhone.Country.list/1","doc":"This function returns all known countries as `LivePhone.Country` structs,\nsorted alphabetically by country name.\n\nOptionally you can specify a list of preferred country codes, and these will\nbe put at the top of the list.\n\n```elixir\n# This will return everything alphabetically\nabc_countries = LivePhone.Country.list()\n\n# This will return it alphabetically as well, but push\n# the US and GB `LivePhone.Country` structs to the top\n# of the list.\nmy_countries = LivePhone.Country.list([\"US\", \"GB\"])\n```","ref":"LivePhone.Country.html#list/1"},{"type":"type","title":"LivePhone.Country.phone/0","doc":"","ref":"LivePhone.Country.html#t:phone/0"},{"type":"type","title":"LivePhone.Country.t/0","doc":"","ref":"LivePhone.Country.html#t:t/0"},{"type":"module","title":"LivePhone.Util","doc":"","ref":"LivePhone.Util.html"},{"type":"function","title":"LivePhone.Util.emoji_for_country/1","doc":"Parses the given `country_code` into an emoji, but I should note that the\nemoji is not validated so it might return an invalid emoji (this will also\ndepend on the unicode version supported by your operating system, and which\nflags are included.)","ref":"LivePhone.Util.html#emoji_for_country/1"},{"type":"function","title":"Examples - LivePhone.Util.emoji_for_country/1","doc":"iex> Util.emoji_for_country(nil)\n    \"\"\n\n    iex> Util.emoji_for_country(\"US\")\n    \"🇺🇸\"","ref":"LivePhone.Util.html#emoji_for_country/1-examples"},{"type":"function","title":"LivePhone.Util.get_country/1","doc":"This is used to try and get a `Country` for a given phone number.","ref":"LivePhone.Util.html#get_country/1"},{"type":"function","title":"Examples - LivePhone.Util.get_country/1","doc":"iex> Util.get_country(\"\")\n    {:error, :invalid_number}\n\n    iex> Util.get_country(\"+1555\")\n    {:error, :invalid_number}\n\n    iex> Util.get_country(\"+1555\")\n    {:error, :invalid_number}\n\n    iex> Util.get_country(\"+1 (555) 555-1234\")\n    {:error, :invalid_number}\n\n    iex> Util.get_country(\"+1 (555) 555-1234\")\n    {:error, :invalid_number}\n\n    iex> Util.get_country(\"+1 (650) 253-0000\")\n    {:ok, %LivePhone.Country{code: \"US\", flag_emoji: \"🇺🇸\",\n      name: \"United States of America (the)\", preferred: false, region_code: \"1\"}}\n\n    iex> Util.get_country(\"+16502530000\")\n    {:ok, %LivePhone.Country{code: \"US\", flag_emoji: \"🇺🇸\",\n      name: \"United States of America (the)\", preferred: false, region_code: \"1\"}}","ref":"LivePhone.Util.html#get_country/1-examples"},{"type":"function","title":"LivePhone.Util.normalize/2","doc":"This is used to normalize a given `phone` number to E.164 format, and returns\na tuple with `{:ok, formatted_phone}` for valid numbers and `{:error,\nunformatted_phone}` for invalid numbers.","ref":"LivePhone.Util.html#normalize/2"},{"type":"function","title":"Examples - LivePhone.Util.normalize/2","doc":"iex> Util.normalize(\"1234\", nil)\n    {:error, \"1234\"}\n\n    iex> Util.normalize(\"+1234\", nil)\n    {:ok, \"+1234\"}\n\n    iex> Util.normalize(\"+1 (650) 253-0000\", \"US\")\n    {:ok, \"+16502530000\"}","ref":"LivePhone.Util.html#normalize/2-examples"},{"type":"function","title":"LivePhone.Util.valid?/1","doc":"This is used to verify a given phone number and see if it is a valid number\naccording to ExPhoneNumber.","ref":"LivePhone.Util.html#valid?/1"},{"type":"function","title":"Examples - LivePhone.Util.valid?/1","doc":"iex> Util.valid?(\"\")\n    false\n\n    iex> Util.valid?(\"+1555\")\n    false\n\n    iex> Util.valid?(\"+1555\")\n    false\n\n    iex> Util.valid?(\"+1 (555) 555-1234\")\n    false\n\n    iex> Util.valid?(\"+1 (555) 555-1234\")\n    false\n\n    iex> Util.valid?(\"+1 (650) 253-0000\")\n    true\n\n    iex> Util.valid?(\"+16502530000\")\n    true","ref":"LivePhone.Util.html#valid?/1-examples"},{"type":"extras","title":"README","doc":"[![Actions Status](https://github.com/nkezhaya/live_phone/actions/workflows/elixir.yml/badge.svg)](https://github.com/nkezhaya/live_phone/actions/workflows/elixir.yml?query=workflow%3ACI)\n[![hex.pm](https://img.shields.io/hexpm/v/live_phone.svg)](https://hexdocs.pm/live_phone/LivePhone.html)\n\n# LivePhone\n\nA Phoenix LiveComponent for phone number input fields, inspired by [`intl-tel-input`](https://github.com/jackocnr/intl-tel-input).\n\nBased on [`ISO`](https://github.com/nkezhaya/iso) and [`ex_phone_number`](https://github.com/socialpaymentsbv/ex_phone_number), which in turn is based on [libphonenumber](https://github.com/google/libphonenumber).","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `live_phone` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_phone, \"~> 0.8\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at [https://hexdocs.pm/live_phone](https://hexdocs.pm/live_phone).\n\nTo your `assets/package.json` file add:\n```\n\"live_phone\": \"file:../deps/live_phone\",\n```\n\nTo your `app.js` add something like:\n```\nimport LivePhone from \"live_phone\"\nlet Hooks = {}\nHooks.LivePhone = LivePhone\n```\n\nAnd finally to your CSS add:\n```\n@import \"../../deps/live_phone/assets/live_phone\";\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"Usage is pretty simple, and there is an example Phoenix project included in the `./example` directory of this repository.\n\n```elixir\n<.live_component\n  module={LivePhone}\n  id=\"phone\"\n  form={:user}\n  field={:phone}\n  tabindex={0}\n  preferred={[\"US\", \"CA\"]} />\n```\n\nThis will result in a form field with the name `user[phone]`. You can specify just the `name` manually if desired, but when you add the `form` option the name will be generated via `Phoenix.HTML.Form.input_name/2`. So this should behave like a regular input field.\n\nWith `preferred` you can set a list of countries that you believe should be on top always. The currently selected country will also be on top automatically.","ref":"readme.html#usage"},{"type":"extras","title":"Example - README","doc":"In the `example/` directory you will find a minimal Phoenix application to demonstrate `LivePhone` in usage.","ref":"readme.html#example"},{"type":"extras","title":"Browser Tests (chromedriver) - README","doc":"To run the browser tests you need to install `chromedriver` (`brew install chromedriver` on MacOS) and it has to be running already. The tests are excluded by default, but you can include them with `--include browser`. See below:\n\nAn \"invalid session id\" error can usually be fixed by upgrading chromedriver.\n\n```\n$ chromedriver --verbose --url-base=/wd/hub # hound assumes default port 9515)\n$ mix test --include browser\n```","ref":"readme.html#browser-tests-chromedriver"}],"content_type":"text/markdown"}